=======
Credits
=======

Development Lead
----------------

* John Whitlock <john@factorialfive.com>

Contributors
------------

* `fpruitt <https://github.com/fpruitt>`_
* `creynold <https://github.com/creynold>`_
